@@ -1,14 +1,14 @@
 use strict;
 use warnings;
 package Software::License::GFDL_1_2;
-BEGIN {
-  $Software::License::GFDL_1_2::VERSION = '0.102340';
+{
+  $Software::License::GFDL_1_2::VERSION = '0.103004';
 }
 use base 'Software::License';
-# ABSTRACT: The GNU Free Documentation License
+# ABSTRACT: The GNU Free Documentation License v1.2
 
-sub name { 'GNU Free Documentation License' }
-sub url  { 'http://www.gnu.org/copyleft/fdl.html' }
+sub name { 'GNU Free Documentation License v1.2' }
+sub url  { 'http://www.gnu.org/licenses/fdl-1.2.html' }
 sub meta_name  { 'open_source' }
 sub meta2_name { 'gfdl_1_2' }
 
@@ -19,11 +19,11 @@ sub meta2_name { 'gfdl_1_2' }
 
 =head1 NAME
 
-Software::License::GFDL_1_2 - The GNU Free Documentation License
+Software::License::GFDL_1_2 - The GNU Free Documentation License v1.2
 
 =head1 VERSION
 
-version 0.102340
+version 0.103004
 
 =head1 AUTHOR
 
@@ -31,7 +31,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2011 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -54,7 +54,8 @@ __LICENSE__
 
 
  Copyright (C) 2000,2001,2002  Free Software Foundation, Inc.
-     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ 51 Franklin St, Suite 500, Boston, MA  02110-1335  USA
+
  Everyone is permitted to copy and distribute verbatim copies
  of this license document, but changing it is not allowed.
 
